summaryrefslogtreecommitdiffstats
path: root/tools/libtest
diff options
context:
space:
mode:
authorJordan Henderson <jhenderson@hdfgroup.org>2020-02-11 23:57:19 (GMT)
committerJordan Henderson <jhenderson@hdfgroup.org>2020-03-17 19:25:36 (GMT)
commitfa087c39199fccc1686b122e67b56e06c8fbe313 (patch)
treed6e6a8a1b8650d454256f32efc635d04edd94d43 /tools/libtest
parent7613f7e1aa89210bb625d59d79a6220c49a1f22c (diff)
downloadhdf5-fa087c39199fccc1686b122e67b56e06c8fbe313.zip
hdf5-fa087c39199fccc1686b122e67b56e06c8fbe313.tar.gz
hdf5-fa087c39199fccc1686b122e67b56e06c8fbe313.tar.bz2
Update Tools library to be better compatible with VOL connectors
Modify h5repack to integrate with VOL connectors Update tools library to accomodate VOL connectors Update logic in h5tools_fopen for VOL connectors Add command-line options to h5repack for specifying in/out VOL connectors Implement h5tools_set_vol_fapl Fix library shutdown issue Integrate ROS3 and HDFS VFDs into new h5tools_get_fapl() scheme Avoid H5Ocopy in h5repack when using different VOL connectors Update h5tools_test_utils.c for ROS3 and HDFS integration
Diffstat (limited to 'tools/libtest')
-rw-r--r--tools/libtest/h5tools_test_utils.c18
1 files changed, 11 insertions, 7 deletions
diff --git a/tools/libtest/h5tools_test_utils.c b/tools/libtest/h5tools_test_utils.c
index 726f4c4..160e06f 100644
--- a/tools/libtest/h5tools_test_utils.c
+++ b/tools/libtest/h5tools_test_utils.c
@@ -960,7 +960,7 @@ error :
*
* Function: test_set_configured_fapl()
*
* Purpose: Verify `h5tools_set_configured_fapl()` with ROS3 VFD
*
* Return: 0 if test passes
* 1 if failure
@@ -1147,7 +1147,8 @@ test_set_configured_fapl(void)
TESTING("programmatic fapl set");
for (i = 0; i < n_cases; i++) {
- int result;
+ h5tools_get_fapl_info_t get_fapl_info;
+ hid_t result;
testcase C = cases[i];
fapl_id = H5I_INVALID_HID;
@@ -1169,11 +1170,14 @@ test_set_configured_fapl(void)
#endif /* UTIL_TEST_DEBUG */
/* test */
- result = h5tools_set_configured_fapl(
- fapl_id,
- C.vfdname,
- C.conf_fa);
- JSVERIFY( result, C.expected, C.message )
+ get_fapl_info.get_type = GET_VFD_BY_NAME;
+ get_fapl_info.info = C.conf_fa;
+ get_fapl_info.u.name = C.vfdname;
+ result = h5tools_get_fapl(H5P_DEFAULT, &get_fapl_info);
+ if (C.expected == 0)
+ JSVERIFY( result, H5I_INVALID_HID, C.message)
+ else
+ JSVERIFY_NOT( result, H5I_INVALID_HID, C.message)
#if UTIL_TEST_DEBUG
HDfprintf(stderr, "after test\n"); fflush(stderr);
@@ -960,7 +960,7 @@ error :
* Function: test_set_configured_fapl()
*
- * Purpose: Verify `h5tools_set_configured_fapl()` with ROS3 VFD
+ * Purpose: Verify `h5tools_get_fapl()` with ROS3 and HDFS VFDs
*
* Return: 0 if test passes